@@ -132,35 +132,35 @@ DominoConfig::DominoConfig( TDEConfig* config, TQWidget* parent )
 	load(config);
 
 	// Ensure we track user changes properly
-	connect(customGradientColors, SIGNAL(toggled(bool)), topGradientColor, SLOT(setEnabled(bool)));
-	connect(customGradientColors, SIGNAL(toggled(bool)), bottomGradientColor, SLOT(setEnabled(bool)));
+	connect(customGradientColors, TQ_SIGNAL(toggled(bool)), topGradientColor, TQ_SLOT(setEnabled(bool)));
+	connect(customGradientColors, TQ_SIGNAL(toggled(bool)), bottomGradientColor, TQ_SLOT(setEnabled(bool)));
 	
-	connect(customBorderColor, SIGNAL(toggled(bool)), borderColor, SLOT(setEnabled(bool)));
-	connect(customButtonColor, SIGNAL(toggled(bool)), buttonColor, SLOT(setEnabled(bool)));
-	connect(customButtonIconColor, SIGNAL(toggled(bool)), buttonIconColor, SLOT(setEnabled(bool)));
+	connect(customBorderColor, TQ_SIGNAL(toggled(bool)), borderColor, TQ_SLOT(setEnabled(bool)));
+	connect(customButtonColor, TQ_SIGNAL(toggled(bool)), buttonColor, TQ_SLOT(setEnabled(bool)));
+	connect(customButtonIconColor, TQ_SIGNAL(toggled(bool)), buttonIconColor, TQ_SLOT(setEnabled(bool)));
 	
-	connect(customGradientColors, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(topGradientColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
-	connect(bottomGradientColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+	connect(customGradientColors, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(topGradientColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
+	connect(bottomGradientColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
 	
 	
-	connect(customBorderColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(borderColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+	connect(customBorderColor, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(borderColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
 	
-	connect(customButtonColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(buttonColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
-	connect(customButtonIconColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(buttonIconColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+	connect(customButtonColor, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(buttonColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
+	connect(customButtonIconColor, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(buttonIconColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
 	
-	connect(showInactiveButtons, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(showButtonIcons, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(darkFrame, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
+	connect(showInactiveButtons, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(showButtonIcons, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(darkFrame, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
 	
-	connect(useDominoStyleContourColors, SIGNAL(clicked()), this, SLOT(loadButtonContourColors()));
-	connect(useDominoStyleContourColors, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
-	connect(buttonContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
-	connect(buttonMouseOverContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
-	connect(buttonPressedContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+	connect(useDominoStyleContourColors, TQ_SIGNAL(clicked()), this, TQ_SLOT(loadButtonContourColors()));
+	connect(useDominoStyleContourColors, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectionChanged()));
+	connect(buttonContourColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
+	connect(buttonMouseOverContourColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
+	connect(buttonPressedContourColor, TQ_SIGNAL(changed(const TQColor&)), this, TQ_SLOT(slotSelectionChanged()));
 	
 	
 	// Make the widgets visible in twindecoration valueChanged
