@@ -25,6 +25,7 @@
 
 #include <tdeconfig.h>
 #include <tdeglobal.h>
+#include <tdelocale.h>
 #include <tqlayout.h>
 #include <tqbitmap.h>
 #include <tqimage.h>
@@ -105,7 +106,10 @@ const int borderWidth = 5;
 DominoHandler::DominoHandler()
 {
 	int ignore, maj, min;
-	
+
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
+	TDEGlobal::locale()->insertCatalogue("twin_domino");
+
 	if(XShapeQueryExtension(tqt_xdisplay(), &ignore, &ignore) &&
 		  XShapeQueryVersion(tqt_xdisplay(), &maj, &min) &&
 		  maj >= 1 && min >= 1) {
@@ -651,7 +655,7 @@ DominoClient::~DominoClient()
 
 TQString DominoClient::visibleName() const
 {
-	return "Domino";
+	return i18n("Domino");
 }
 
 TQString DominoClient::defaultButtonsLeft() const
@@ -736,7 +740,7 @@ KCommonDecorationButton *DominoClient::createButton(ButtonType type)
 		case MenuButton: {
 			DominoButton* menu = new DominoButton(MenuButton, this, "menu");
 			menuButton = menu;
-			connect(menu, SIGNAL(destroyed()), this, SLOT(menuButtonDestroyed()));
+			connect(menu, TQ_SIGNAL(destroyed()), this, TQ_SLOT(menuButtonDestroyed()));
 			return menu;
 			break;
 		}
@@ -785,8 +789,8 @@ void DominoClient::init()
 
 	KCommonDecoration::reset(SettingButtons);
 	iconChange();
-	connect(this, SIGNAL(keepAboveChanged(bool) ), SLOT(keepAboveChange(bool) ) );
-	connect(this, SIGNAL(keepBelowChanged(bool) ), SLOT(keepBelowChange(bool) ) );
+	connect(this, TQ_SIGNAL(keepAboveChanged(bool) ), TQ_SLOT(keepAboveChange(bool) ) );
+	connect(this, TQ_SIGNAL(keepBelowChanged(bool) ), TQ_SLOT(keepBelowChange(bool) ) );
 }
 
 void DominoClient::createLayout()
